@@ -14,6 +14,6 @@ class Webhook(AllResource, CreateResource, DeleteResource):
         """Update a webhook."""
         requestor = Requestor(local_api_key=self._api_key)
         url = self.instance_url()
-        response, api_key = requestor.request(method=RequestMethod.PUT, url=url, params=params)
+        response, api_key = requestor.request(method=RequestMethod.PATCH, url=url, params=params)
         self.refresh_from(values=response, api_key=api_key)
         return self
